@@ -26,6 +26,8 @@ use constant {
     UNKNOWN         => 'unknown',
     KILLME          => 'killme',
     #
+    PROC_ROOT       => '/proc',
+    #
     JSONRPC         => '2.0',
     DEFAULT_ADDRESS => '127.0.0.1',
     DEFAULT_PORT    => '9505',
@@ -43,13 +45,13 @@ our $EXPORT_ALL = 'START STOP RELOAD RUNNING ALIVE DEAD SHUTDOWN
                    RELOADED STARTED JSONRPC DEFAULT_PORT DEFAULT_ADDRESS
                    ERR_PARSE ERR_REQ ERR_METHOD ERR_PARAMS ERR_INTERNAL
                    ERR_SERVER SRV_ERR_MAX SRV_ERR_MIN STOPPED UNKNOWN 
-                   EXIT EXITED KILLME STAT STATED';
+                   EXIT EXITED KILLME STAT STATED PROC_ROOT';
 
 our $EXPORT_ANY = 'START STOP RELOAD RUNNING ALIVE DEAD SHUTDOWN 
                    RELOADED STARTED JSONRPC DEFAULT_PORT DEFAULT_ADDRESS
                    ERR_PARSE ERR_REQ ERR_METHOD ERR_PARAMS ERR_INTERNAL
                    ERR_SERVER SRV_ERR_MAX SRV_ERR_MIN STOPPED UNKNOWN
-                   EXIT EXITED KILLME STAT STATED';
+                   EXIT EXITED KILLME STAT STATED PROC_ROOT';
 
 our $EXPORT_TAGS = {
     rpc => 'JSONRPC DEFAULT_PORT DEFAULT_ADDRESS ERR_PARSE ERR_REQ ERR_METHOD
